==> modx-2.2.1-pl-ja.zip: modx-2.2.1-pl-ja/core/lexicon/ja/plugin.inc.php <==
<?php
/**
* Plugin Japanese lexicon topic
*
* @language ja
* @package modx
* @subpackage lexicon
* @author Nick http://smallworld.west-tokyo.com
* @author shimojo http://www.priqia.com/
* @author yamamoto http://kyms.jp
* @author honda http://kogus.org
*/
$_lang['event'] = 'イベント';
$_lang['events'] = 'イベント';
$_lang['plugin'] = 'プラグイン';
$_lang['plugin_add'] = 'プラグイン追加';
$_lang['plugin_add_to_event'] = 'イベントへプラグインを追加';
$_lang['plugin_code'] = 'プラグイン コード (php)';
$_lang['plugin_config'] = 'プラグイン設定';
$_lang['plugin_desc'] = '説明';
$_lang['plugin_desc_category'] = 'このプラグインが所属するカテゴリー';
$_lang['plugin_desc_description'] = 'プラグインの簡単な説明';
$_lang['plugin_desc_name'] = 'このプラグインの名前';
$_lang['plugin_delete_confirm'] = 'プラグインを削除しますか?';
$_lang['plugin_disabled'] = 'プラグインの停止';
$_lang['plugin_duplicate_confirm'] = 'プラグインを複製しますか?';
$_lang['plugin_err_create'] = 'プラグインの作成中にエラーが発生しました。';
$_lang['plugin_err_exists_name'] = '[[+name]]という名前のプラグインがすでに存在します。';
$_lang['plugin_err_invalid_name'] = 'プラグイン名は無効です。';
$_lang['plugin_err_nf'] = 'プラグインが見つかりません。';
$_lang['plugin_err_ns'] = 'プラグインが指定されていません。';
$_lang['plugin_err_ns_name'] = 'プラグインの名前を指定してください。';
$_lang['plugin_err_remove'] = 'プラグインの削除中にエラーが発生しました。';
$_lang['plugin_err_save'] = 'プラグインの保存中にエラーが発生しました。';
$_lang['plugin_event_err_duplicate'] = 'プラグインのイベントを複製中にエラーが発生しました。';
$_lang['plugin_event_err_nf'] = 'プラグインのイベントが見つかりませでした。';
$_lang['plugin_event_err_ns'] = 'プラグインのイベントを特定できませんでした。';
$_lang['plugin_event_err_remove'] = 'プラグインのイベント削除中にエラーが発生しました。';
$_lang['plugin_event_err_save'] = 'プラグインのイベントを保存中にエラーが発生しました。';
$_lang['plugin_event_msg'] = 'このプラグインが使用するイベントを選択してください。';
$_lang['plugin_event_plugin_remove_confirm'] = 'このイベントからこのプラグインを削除しますか？';
$_lang['plugin_event_update'] = 'プラグインイベントを編集';
$_lang['plugin_lock'] = '編集のためプラグインをロック';
$_lang['plugin_lock_msg'] = 'このプラグインを編集するためには、編集のためのロック属性が必要です。';
$_lang['plugin_locked_message'] = 'このプラグインはロックされてます。';
$_lang['plugin_management_msg'] = '<h3 style="font-weight:bold;">プラグインの管理</h3><p>編集したいプラグインを選択します。</p>';
$_lang['plugin_msg'] = 'プラグインの追加や編集をすることができます。プラグインは選択したシステムイベントの発生時に実行されるPHPのコード群です。';
$_lang['plugin_name'] = 'プラグイン名';
$_lang['plugin_new'] = '新しいプラグイン';
$_lang['plugin_priority'] = 'イベント発生時のプラグインの実行順を編集';
$_lang['plugin_properties'] = 'プラグインプロパティ';
$_lang['plugin_title'] = 'プラグインの作成/編集';
$_lang['plugin_untitled'] = '無名のプラグイン';
$_lang['plugins'] = 'プラグイン';

==> modx-2.3.3-pl-ja.zip: modx-2.3.3-pl-ja/core/lexicon/ja/plugin.inc.php <==
<?php
/**
 * Plugin English lexicon topic
 *
 * @language en
 * @package modx
 * @subpackage lexicon
 */
$_lang['event'] = 'イベント';
$_lang['events'] = 'イベント';
$_lang['plugin'] = 'プラグイン';
$_lang['plugin_add'] = 'プラグイン追加';
$_lang['plugin_add_to_event'] = 'イベントへプラグインを追加';
$_lang['plugin_code'] = 'プラグイン コード（php）';
$_lang['plugin_config'] = 'プラグイン設定';
$_lang['plugin_desc'] = '説明';
$_lang['plugin_desc_category'] = 'このプラグインを所属させるカテゴリーを設定します。';
$_lang['plugin_desc_description'] = 'プラグインの説明文を設定します。';
$_lang['plugin_desc_name'] = 'プラグインの名前を設定します。';
$_lang['plugin_delete_confirm'] = 'プラグインを削除しますか？';
$_lang['plugin_disabled'] = 'プラグインの停止';
$_lang['plugin_duplicate_confirm'] = 'プラグインを複製しますか？';
$_lang['plugin_err_create'] = 'プラグインの作成中にエラーが発生しました。';
$_lang['plugin_err_exists_name'] = '[[+name]]という名前のプラグインがすでに存在します。';
$_lang['plugin_err_invalid_name'] = 'プラグイン名は無効です。';
$_lang['plugin_err_nf'] = 'プラグインが見つかりません。';
$_lang['plugin_err_ns'] = 'プラグインが指定されていません。';
$_lang['plugin_err_ns_name'] = 'プラグインの名前を指定してください。';
$_lang['plugin_err_remove'] = 'プラグインの削除中にエラーが発生しました。';
$_lang['plugin_err_save'] = 'プラグインの保存中にエラーが発生しました。';
$_lang['plugin_event_err_duplicate'] = 'プラグインのイベントを複製中にエラーが発生しました。';
$_lang['plugin_event_err_nf'] = 'プラグインのイベントが見つかりませでした。';
$_lang['plugin_event_err_ns'] = 'プラグインのイベントを特定できませんでした。';
$_lang['plugin_event_err_remove'] = 'プラグインのイベント削除中にエラーが発生しました。';
$_lang['plugin_event_err_save'] = 'プラグインのイベントを保存中にエラーが発生しました。';
$_lang['plugin_event_msg'] = 'このプラグインが使用するイベントを選択してください。';
$_lang['plugin_event_plugin_remove_confirm'] = 'このイベントからこのプラグインを削除しますか？';
$_lang['plugin_event_update'] = 'プラグインイベントを編集';
$_lang['plugin_lock'] = '編集のためプラグインをロック';
$_lang['plugin_lock_msg'] = 'このプラグインを編集するためには、編集のためのロック属性が必要です。';
$_lang['plugin_locked_message'] = 'このプラグインはロックされてます。';
$_lang['plugin_management_msg'] = '<h3 style="font-weight:bold;">プラグインの管理</h3><p>編集したいプラグインを選択します。</p>';
$_lang['plugin_msg'] = 'プラグインの追加や編集をすることができます。プラグインは選択したシステムイベントの発生時に実行されるPHPのコード群です。';
$_lang['plugin_name'] = 'プラグイン名';
$_lang['plugin_new'] = '新しいプラグイン';
$_lang['plugin_priority'] = 'イベント発生時のプラグインの実行順を編集';
$_lang['plugin_properties'] = 'プラグインプロパティ';
$_lang['plugin_title'] = 'プラグインの作成/編集';
$_lang['plugin_untitled'] = '無名のプラグイン';
$_lang['plugins'] = 'プラグイン';
